@@ -1,3 +1,5 @@
+import sys
+
 from ploomber.cli.parsers import CustomParser
 from ploomber.cli.io import cli_endpoint
 from ploomber.executors import Parallel
@@ -9,7 +11,7 @@ import datetime
 @cli_endpoint
 def main(render_only=False):
     start_time = datetime.datetime.now()
-    parser = CustomParser(description='Build pipeline')
+    parser = CustomParser(description='Build pipeline', prog='ploomber build')
 
     with parser:
         parser.add_argument('--force',
@@ -35,6 +37,19 @@ def main(render_only=False):
             action='store_true',
             default=False)
 
+    # users may try to run "ploomber build {name}" to build a single task
+    if len(sys.argv) > 1 and not sys.argv[1].startswith('-'):
+        suggestion = 'ploomber task {task-name}'
+        cmd_name = parser.prog
+        telemetry.log_api("unsupported_build_cmd",
+                          metadata={
+                              'cmd_name': cmd_name,
+                              'suggestion': suggestion,
+                              'argv': sys.argv
+                          })
+        parser.error(f'{cmd_name!r} does not take positional arguments.\n'
+                     f'To build a single task, try: {suggestion!r}')
+
     dag, args = parser.load_from_entry_point_arg()
 
     # when using the parallel executor from the CLI, ensure we print progress
@@ -57,5 +72,7 @@ def main(render_only=False):
             print(report)
     end_time = datetime.datetime.now()
     telemetry.log_api("ploomber_build",
-                      total_runtime=str(end_time - start_time))
+                      total_runtime=str(end_time - start_time),
+                      dag=dag,
+                      metadata={'argv': sys.argv})
     return dag
