@@ -1,6 +1,8 @@
 from pathlib import Path
 from io import StringIO
 
+from jinja2 import Template
+
 from ploomber.tasks.abc import Task
 from ploomber.tasks.mixins import ClientMixin
 from ploomber.sources import (SQLScriptSource, SQLQuerySource, FileSource)
@@ -8,6 +10,8 @@ from ploomber.products import (File, PostgresRelation, SQLiteRelation,
                                GenericSQLRelation, GenericProduct, SQLRelation)
 from ploomber import io
 from ploomber.util import requires
+from ploomber.placeholders.placeholder import _add_globals
+from ploomber.exceptions import SQLExecuteError
 
 
 class SQLScript(ClientMixin, Task):
@@ -61,7 +65,12 @@ class SQLScript(ClientMixin, Task):
         self.dag = dag
 
     def run(self):
-        return self.client.execute(str(self.source))
+        source_code = str(self.source)
+
+        try:
+            return self.client.execute(source_code)
+        except Exception as e:
+            raise SQLExecuteError(type(self), source_code, e) from e
 
     def load(self, limit=10):
         """Load this task's product in a pandas.DataFrame
@@ -154,14 +163,25 @@ class SQLDump(io.FileLoaderMixin, ClientMixin, Task):
         return SQLQuerySource(source, **kwargs)
 
     def run(self):
-        source_code = str(self.source)
+
+        # render runtime parameters
+        template = Template(str(self.source),
+                            variable_start_string='[[',
+                            variable_end_string=']]')
+        _add_globals(template.environment)
+        source_code = template.render(upstream=self.params.get('upstream'))
+
         path = Path(str(self.params['product']))
         handler = self.io_handler(path, chunked=bool(self.chunksize))
 
         self._logger.debug('Code: %s', source_code)
 
         cursor = self.client.connection.cursor()
-        cursor.execute(source_code)
+
+        try:
+            cursor.execute(source_code)
+        except Exception as e:
+            raise SQLExecuteError(type(self), source_code, e) from e
 
         if self.chunksize:
             i = 1
