@@ -5,7 +5,7 @@ This is optional and may be turned off by changing the configuration file:
  inside ~/.ploomber/config/config.yaml
  Change stats_enabled to False.
 See the user stats page for more information:
-https://ploomber.readthedocs.io/en/latest/community/user-stats.html
+https://docs.ploomber.io/en/latest/community/user-stats.html
 
 The data we collect is limited to:
 1. The Ploomber version currently running.
@@ -39,6 +39,7 @@ import os
 from pathlib import Path
 import sys
 import uuid
+from functools import wraps
 
 from ploomber.telemetry import validate_inputs
 from ploomber import __version__
@@ -417,3 +418,30 @@ def log_api(action,
                             properties=props)
 
         posthog.capture(distinct_id=uid, event=action, properties=props)
+
+
+def log_exception(action):
+    """Runs a function and logs exceptions, if any
+    """
+
+    def _log_exceptions(func):
+
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            try:
+                start = datetime.datetime.now()
+                return func(*args, **kwargs)
+            except Exception as e:
+                log_api(
+                    action=action,
+                    total_runtime=str(datetime.datetime.now() - start),
+                    metadata={
+                        # can we log None to posthog?
+                        'type': getattr(e, 'type_', ''),
+                        'exception': str(e),
+                    })
+                raise e
+
+        return wrapper
+
+    return _log_exceptions
