@@ -2,7 +2,7 @@ import sys
 import os
 from pathlib import Path, WindowsPath
 import importlib
-from functools import wraps, reduce
+from functools import wraps
 import base64
 import shutil
 import inspect
@@ -24,7 +24,7 @@ def requires(pkgs, name=None, extra_msg=None, pip_names=None):
 
     Parameters
     ----------
-    pkgs
+    pkgs : list
         The names of the packages required
 
     name
@@ -34,7 +34,7 @@ def requires(pkgs, name=None, extra_msg=None, pip_names=None):
     extra_msg
         Append this extra message to the end
 
-    pip_names
+    pip_names : list
         Pip package names to show in the suggested "pip install {name}"
         command, use it if different to the package name itself
 
@@ -51,22 +51,12 @@ def requires(pkgs, name=None, extra_msg=None, pip_names=None):
                     name for name, is_missing in zip(
                         pip_names or pkgs, is_pkg_missing) if is_missing
                 ]
-                names_str = reduce(lambda x, y: x + ' ' + y, missing_pkgs)
 
                 fn_name = name or f.__name__
-                error_msg = ('{} {} required to use {}. Install {} by '
-                             'running "pip install {}"'.format(
-                                 names_str,
-                                 'is' if len(missing_pkgs) == 1 else 'are',
-                                 fn_name,
-                                 'it' if len(missing_pkgs) == 1 else 'them',
-                                 names_str,
-                             ))
 
-                if extra_msg:
-                    error_msg += ('. ' + extra_msg)
-
-                raise ImportError(error_msg)
+                raise ImportError(
+                    _make_requires_error_message(missing_pkgs, fn_name,
+                                                 extra_msg))
 
             return f(*args, **kwargs)
 
@@ -75,6 +65,23 @@ def requires(pkgs, name=None, extra_msg=None, pip_names=None):
     return decorator
 
 
+def _make_requires_error_message(missing_pkgs, fn_name, extra_msg):
+    names_str = ' '.join(repr(pkg) for pkg in missing_pkgs)
+
+    error_msg = ('{} {} required to use {}. Install with: '
+                 'pip install {}'.format(
+                     names_str,
+                     'is' if len(missing_pkgs) == 1 else 'are',
+                     repr(fn_name),
+                     names_str,
+                 ))
+
+    if extra_msg:
+        error_msg += ('\n' + extra_msg)
+
+    return error_msg
+
+
 def safe_remove(path):
     if path.exists():
         if path.is_file():
